********
Glossary
********

.. glossary::

    Directive
        A directive is a extension mechanism for :term:`reStructuredText` used
        by :term:`Sphinx` to provide a generic block of explicit markup.

        .. seealso:: http://www.sphinx-doc.org/en/stable/rest.html#directives

    JavaScript
        Programming language specified in the ECAMScript language specification.

        .. seealso:: http://www.w3schools.com/js/

    reStructuredText
        reStructuredText is a markup language for textual data that uses
        simple and intuitive constructs to indicate the structure of a document.

        .. seealso:: http://www.sphinx-doc.org/en/stable/rest.html

    Sphinx
        Sphinx is a tool that makes it easy to create intelligent and beautiful
        documentation.

        .. seealso:: www.sphinx-doc.org/

    Virtualenv
        A tool to create isolated Python environments.

        .. seealso:: https://virtualenv.pypa.io/en/latest/
